use strict;
use warnings;
package Tapper::TestSuite::Benchmark::S3;
# git description: v4.1.0-1-g2d89e4a

BEGIN {
  $Tapper::TestSuite::Benchmark::S3::AUTHORITY = 'cpan:TAPPER';
}
{
  $Tapper::TestSuite::Benchmark::S3::VERSION = '4.1.1';
}
# ABSTRACT: Measure suspend/resume cycle with external Arduino box

1;



=pod

=encoding utf-8

=head1 NAME

Tapper::TestSuite::Benchmark::S3 - Measure suspend/resume cycle with external Arduino box

=head1 ABOUT

This testsuite triggers suspend resume cycle with an external Arduino
box and reports values into Tapper suiting automatic passthrough to
Codespeed graph rendering application.

=head1 AUTHOR

AMD OSRC Tapper Team <tapper@amd64.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..

This is free software, licensed under:

  The (two-clause) FreeBSD License

=cut


__END__

